from sqlalchemy import Sequence
from sqlalchemy.orm import Session
from sqlalchemy.sql.ddl import DropSequence, CreateSequence

from afeng_tools.sqlalchemy_tool.core.sqlalchemy_session_decorator import auto_commit_db


@auto_commit_db()
def create_sequence(sequence_name: str, db: Session = None):
    # create sequence {sequence_name} start with 1 increment by 1 nocache nocycle
    db.execute(CreateSequence(Sequence(name=sequence_name, start=1, increment=1, cycle=False, cache=False),
                              if_not_exists=True))


@auto_commit_db()
def drop_sequence(sequence_name: str, db: Session = None):
    db.execute(DropSequence(Sequence(sequence_name)))



from starlette.responses import Response
from starlette.templating import Jinja2Templates
from starlette.requests import Request


def create_jinja2_templates(template_folder: str):
    return Jinja2Templates(directory=template_folder)


jinja2_templates_dict = create_jinja2_templates('template')


def create_template_response(request: Request, template_file: str, context: dict = None) -> Response:
    """
    创建模板响应
    :param request: Request
    :param template_file: 模板文件
    :param context: 上下文内容
    :return:
    """
    if not context:
        context = dict()
    if 'request' not in context:
        context['request'] = request
    return jinja2_templates.TemplateResponse(template_file, context=context)



from enum import Enum
from typing import Callable

from pydantic import BaseModel

from afeng_tools.weixin_tool.core.model.item.wx_receive_event_models import WeixinEventItem, WeixinSubscribeEventItem, \
    WeixinQrEventItem, WeixinScanEventItem, WeixinLocationEventItem, WeixinMenuEventItem
from afeng_tools.weixin_tool.core.model.item.wx_receive_msg_models import WeixinVoiceMsgItem, WeixinTextMsgItem, \
    WeixinImageMsgItem, WeixinVideoMsgItem, WeixinLocationMsgItem, WeixinLinkMsgItem
from afeng_tools.weixin_tool.core.response import XmlResponse


class WeixinConfigItem(BaseModel):
    """微信配置枚举"""
    weixin_app_id: str
    weixin_app_secret: str
    weixin_token: str
    weixin_encoding_aes_key: str
    weixin_msg_callback: Callable[[
        WeixinTextMsgItem | WeixinImageMsgItem | WeixinVoiceMsgItem | WeixinVideoMsgItem | WeixinLocationMsgItem | WeixinLinkMsgItem | WeixinEventItem | WeixinSubscribeEventItem | WeixinQrEventItem | WeixinScanEventItem | WeixinLocationEventItem | WeixinMenuEventItem], XmlResponse]


class WeixinConfigKeyEnum(Enum):
    """微信配置枚举"""
    weixin_app_id = 'weixin_app_id'
    weixin_app_secret = 'weixin_app_secret'
    weixin_token = 'weixin_token'
    weixin_encoding_aes_key = 'weixin_encoding_aes_key'
    weixin_msg_callback = 'weixin_msg_callback'
